==> haskell-tagged-0.8.9-1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tagged
version:              0.8.9
visibility:           public
id:                   tagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP
key:                  tagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP
license:              BSD-3-Clause
copyright:            2009-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/tagged
synopsis:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments

description:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments.

category:             Data, Phantom Types
abi:                  d079dabde5fa34a641b560e62bd58ea9
exposed:              True
exposed-modules:      Data.Proxy.TH Data.Tagged
import-dirs:          /usr/lib/ghc-9.2.8/site-local/tagged-0.8.9
library-dirs:         /usr/lib/ghc-9.2.8/site-local/tagged-0.8.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagged
hs-libraries:         HStagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP
depends:
    base-4.16.4.0 deepseq-1.4.6.1 template-haskell-2.18.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tagged/html/tagged.haddock
haddock-html:         /usr/share/doc/haskell-tagged/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tagged-0.8.9-2.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tagged
version:              0.8.9
visibility:           public
id:                   tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
key:                  tagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
license:              BSD-3-Clause
copyright:            2009-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/tagged
synopsis:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments

description:
    Haskell 98 phantom types to avoid unsafely passing dummy arguments.

category:             Data, Phantom Types
abi:                  f2297261e12828a9dbcb2d72a0fb9416
exposed:              True
exposed-modules:      Data.Proxy.TH Data.Tagged
import-dirs:          /usr/lib/ghc-9.4.8/site-local/tagged-0.8.9
library-dirs:         /usr/lib/ghc-9.4.8/site-local/tagged-0.8.9
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/tagged-0.8.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tagged
hs-libraries:         HStagged-0.8.9-KMS3sfDasKWItFZcxfaN6C
depends:
    base-4.17.2.1 deepseq-1.4.8.0 template-haskell-2.19.0.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-tagged/html/tagged.haddock
haddock-html:         /usr/share/doc/haskell-tagged/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
